@@ -1,6 +1,6 @@
 package Net::Gnats;
 BEGIN {
-  $Net::Gnats::VERSION = '0.17';
+  $Net::Gnats::VERSION = '0.18';
 }
 use 5.010_000;
 use utf8;
@@ -19,7 +19,7 @@ use Net::Gnats::Constants qw(CODE_OK CODE_GREETING CODE_INFORMATION CODE_TEXT_RE
                              CODE_SEND_PR CODE_SEND_TEXT CODE_FILE_ERROR
                              RESTART_CHECK_THRESHOLD
                              CODE_INFORMATION_FILLER
-                             CODE_NO_PRS_MATCHED 
+                             CODE_NO_PRS_MATCHED
                              CODE_INVALID_EXPR CODE_INVALID_QUERY_FORMAT
                              CODE_PR_READY CODE_INVALID_DATABASE
                              LF CR CRLF DOT CONT MAX_NEW_PRS);
@@ -424,7 +424,7 @@ sub list_states {
                        )->formatted;
 }
 
-=item list_fieldnames
+=head2 list_fieldnames
 
 Issues the LIST FIELDNAMES command, and returns a list of hashrefs
 with key 'name'.
@@ -464,16 +464,23 @@ sub list_inputfields_initial_required {
 
 =head2 get_field_type
 
-Expects a fieldname as sole argument, and issues the FTYP command.
-Returns text response or undef if error.
+Expects a single fieldname or an anonymous array of field types.
+
+Returns 0 if the type information could not be retrieved.
+
+Returns a list of types based on the number of fields passed.
 
 =cut
 
 sub get_field_type {
   my ( $self, $field ) = @_;
-  if (not defined $field) { return 0; }
-  $self->session->issue(Net::Gnats::Command->ftyp(fields => $field)
-                       )->response->as_list;
+
+  return 0 if not defined $field;
+
+  my $c = $self->session->issue(Net::Gnats::Command->ftyp(fields => $field));
+
+  return 0 if not $c->is_ok;
+  return $c->response->as_list;
 }
 
 =head2 get_field_type_info
@@ -946,18 +953,20 @@ sub qfmt {
 Expects one or more query expressions as argument(s).  Returns an
 anonymous array of PR numbers.
 
+If there is an error, then it will return an empty set.
+
 =cut
 
 sub query {
   my $self = shift;
   my @exprs = @_;
 
-  return 0 if not $self->reset_server;
-  return 0 if not $self->qfmt('full');
-  return 0 if not $self->expr(@exprs);
+  return [] if not $self->reset_server;
+  return [] if not $self->qfmt('full');
+  return [] if not $self->expr(@exprs);
 
   my $c = $self->session->issue(Net::Gnats::Command->quer);
-  return 0 if not $c->is_ok;
+  return [] if not $c->is_ok;
   my $r = $c->response->as_list;
   my @numbers = grep { $_ =~ s/>Number:\s+(.*)/$1/} @{$r};
   return \@numbers;
