@@ -2,7 +2,7 @@ package Net::Gnats::Command::EXPR;
 use parent 'Net::Gnats::Command';
 use strictures;
 BEGIN {
-  $Net::Gnats::VERSION = '0.17';
+  $Net::Gnats::VERSION = '0.18';
 }
 use vars qw($VERSION);
 
@@ -52,12 +52,13 @@ sub as_string {
   my ($self) = @_;
   return undef if not defined $self->{expressions};
   return undef if ref( $self->{expressions} ) ne 'ARRAY';
-  return $c . ' ' . join( ' ', @{$self->{expressions}} );
+  return $c . ' ' . join( ' & ', @{$self->{expressions}} );
 }
 
 sub is_ok {
   my ($self) = @_;
   return 0 if not defined $self->response;
+  return 0 if not defined $self->response->code;
   return 1 if $self->response->code == CODE_OK;
   return 0;
 }
